#
# spec file for package ghc-hyphenation
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hyphenation
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.7
Release:        13.1
Summary:        Configurable Knuth-Liang hyphenation
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cabal-doctest-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-zlib-devel
%if %{with tests}
BuildRequires:  ghc-doctest-devel
%endif

%description
Configurable Knuth-Liang hyphenation

Uses the UTF8 encoded hyphenation patterns provided by hyph-utf8 from
<http://www.ctan.org/tex-archive/language/hyph-utf8>

Usage:

>>> hyphenate english_US "supercalifragilisticexpialadocious"
["su","per","cal","ifrag","ilis","tic","ex","pi","al","ado","cious"]

>>> hyphenate english_US "hyphenation" ["hy","phen","ation"]

>>> hyphenate icelandic "va240lahei240avegavinnuverkf230rageymslusk250r"
["va240la","hei240a","vega","vinnu","verk","f230ra","geymslu","sk250r"].

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%{_datadir}/%{pkg_name}-%{version}/*.hyp.txt.gz
%{_datadir}/%{pkg_name}-%{version}/*.pat.txt.gz
%{_datadir}/%{pkg_name}-%{version}/*.lic.txt.gz
%{_datadir}/%{pkg_name}-%{version}/*.chr.txt.gz

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown

%changelog
* Fri Aug  4 2017 psimons@suse.com
- Update to version 0.7 revision 2.
  * Updated Spanish and Thai hyphenation patterns.
  * Removed Lao patterns until higher quality patterns are available.
  * Updated the licenses associated with many patterns
  * Revamp `Setup.hs` to use `cabal-doctest`. This makes it build
    with `Cabal-2.0`, and makes the `doctest`s work with `cabal new-build` and
    sandboxes.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6 revision 0 with cabal2obs.
